# Overview

[![PyPI Downloads](https://static.pepy.tech/badge/pbi-pyadomd)](https://pepy.tech/projects/pbi-pyadomd)
![Python](https://img.shields.io/badge/python-3.11-blue.svg)
[![Coverage Status](https://coveralls.io/repos/github/douglassimonsen/pbi_pyadomd/badge.svg?branch=main)](https://coveralls.io/github/douglassimonsen/pbi_pyadomd?branch=main)
![Repo Size](https://img.shields.io/github/repo-size/douglassimonsen/pbi_pyadomd)
[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2Fdouglassimonsen%2Fpbi_pyadomd.svg?type=shield&issueType=license)](https://app.fossa.com/projects/git%2Bgithub.com%2Fdouglassimonsen%2Fpbi_pyadomd?ref=badge_shield&issueType=license)
[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2Fdouglassimonsen%2Fpbi_pyadomd.svg?type=shield&issueType=security)](https://app.fossa.com/projects/git%2Bgithub.com%2Fdouglassimonsen%2Fpbi_pyadomd?ref=badge_shield&issueType=security)

pbi_pyadomd is a fork of the original [pyadomd](https://pypi.org/project/pyadomd/) library, designed to provide a typed Python interface for communicating with SQL Server Analysis Services (SSAS) instances. This library allows developers to execute DAX and XML queries against SSAS in a more structured and type-safe manner.

For more information, see the [docs](https://douglassimonsen.github.io/pbi_pyadomd/)

# Installation

```shell
python -m pip install pbi_pyadomd
```
